@@ -659,6 +659,8 @@ mdl_time_forecast.model_fit <- function(object, calibration_data, new_data = NUL
         # setup
         nms_final     <- names(data_formatted)
 
+        # print(nms_final)
+
         if (length(object$preproc$y_var) > 0) {
             fit_interface <-  "formula"
         } else {
@@ -704,9 +706,22 @@ mdl_time_forecast.model_fit <- function(object, calibration_data, new_data = NUL
                 }
             }
 
+            # Issure #228 - fix `.pred_res`
             data_formatted <- actual_data %>%
-                dplyr::bind_rows(data_formatted) %>%
-                dplyr::mutate(.pred = ifelse(is.na(.pred), !! target_sym, .pred))
+                dplyr::bind_rows(data_formatted)
+
+            if (".pred_res" %in% colnames(data_formatted)) {
+                data_formatted <- data_formatted %>%
+                    dplyr::rename(.pred = .pred_res)
+            }
+
+            if (".pred_res" %in% nms_final) {
+                nms_final <- stringr::str_replace(nms_final, ".pred_res", ".pred")
+            }
+
+            data_formatted <- data_formatted %>%
+                dplyr::mutate(.pred = ifelse(is.na(.pred), !! target_sym, .pred)) %>%
+                dplyr::select(!!! rlang::syms(nms_final))
 
         } else {
             # XY Interface
@@ -720,6 +735,16 @@ mdl_time_forecast.model_fit <- function(object, calibration_data, new_data = NUL
 
         }
 
+        # Issue #228 - fix .pred_res
+        if (".pred_res" %in% colnames(data_formatted)) {
+            data_formatted <- data_formatted %>%
+                dplyr::rename(.pred = .pred_res)
+        }
+
+        if (".pred_res" %in% nms_final) {
+            nms_final <- stringr::str_replace(nms_final, ".pred_res", ".pred")
+        }
+
         data_formatted <- data_formatted %>%
             dplyr::select(!!! rlang::syms(nms_final))
 
@@ -998,8 +1023,21 @@ mdl_time_forecast.workflow <- function(object, calibration_data, new_data = NULL
         if (!is.null(actual_data_prepped)) {
             target_sym <- rlang::sym(names(actual_data_prepped)[1])
 
+            # Issue #228 - fix .pred_res
             data_formatted <- actual_data_prepped %>%
-                dplyr::bind_rows(data_formatted) %>%
+                dplyr::bind_rows(data_formatted)
+
+
+            if (".pred_res" %in% colnames(data_formatted)) {
+                data_formatted <- data_formatted %>%
+                    dplyr::rename(.pred = .pred_res)
+            }
+
+            if (".pred_res" %in% nms_final) {
+                nms_final <- stringr::str_replace(nms_final, ".pred_res", ".pred")
+            }
+
+            data_formatted <- data_formatted %>%
                 dplyr::mutate(.pred = ifelse(is.na(.pred), !! target_sym, .pred)) %>%
                 dplyr::select(!!! rlang::syms(nms_final))
         }
@@ -1007,6 +1045,13 @@ mdl_time_forecast.workflow <- function(object, calibration_data, new_data = NULL
     }
 
     # FINALIZE
+
+    # Issue #228 - fix .pred_res
+    if (".pred_res" %in% colnames(data_formatted)) {
+        data_formatted <- data_formatted %>%
+            dplyr::rename(.pred = .pred_res)
+    }
+
     ret <- data_formatted %>%
         dplyr::rename(.value = .pred) %>%
         dplyr::select(.key, .index, .value) %>%
